#squidf: NOTE rebuild yarnpkg after each change of npm version <<<

# This package is inspired by, but not synced with Fedora.

%global nodejs_default_sitelib %{_prefix}/lib/node_modules

# bundle dependencies that are not available as Mageia modules
%bcond_without bootstrap

%{?!_pkgdocdir:%global _pkgdocdir %{_docdir}/%{name}-%{version}}

# ensure compatibility with the mass_rebuild bot
# increment both of these together
#squidf: if v8_version below changes, you can reset v8_release to 1
#squidf: never use subrel or it will mess up v8 versioning
#squidf: no need to change the nodejs_epoch and v8_epoch either
%define rel 3
%global v8_release 3

# == Node.js Version ==
# Note: Mageia should only ship LTS versions of Node.js (currently expected
# to be major versions with even numbers). The odd-numbered versions are new
# feature releases that are only supported for nine months, which is shorter
# than a Mageia release lifecycle.
#squidf: WARNING don't change the epoch
%global nodejs_epoch 1
#
%global nodejs_major 22
%global nodejs_minor 13
%global nodejs_patch 1
# nodejs_soversion - from NODE_MODULE_VERSION in src/node_version.h
%global nodejs_soversion 127
%global nodejs_abi %{nodejs_soversion}
%global nodejs_version %{nodejs_major}.%{nodejs_minor}.%{nodejs_patch}
%global nodejs_release %{rel}

%global nodejs_datadir %{_datarootdir}/node

# == Bundled Dependency Versions ==
# v8 - from deps/v8/include/v8-version.h
# Epoch is set to ensure clean upgrades from the old v8 package
#squidf: WARNING don't change the epoch. Increase v8_release if v8 version doesn't change.
%global v8_epoch 2
#
%global v8_major 12
%global v8_minor 4
%global v8_build 254
%global v8_patch 21
# V8 presently breaks ABI at least every x.y release while never bumping SONAME
%global v8_abi %{v8_major}.%{v8_minor}
%global v8_version %{v8_major}.%{v8_minor}.%{v8_build}.%{v8_patch}

# c-ares - from deps/cares/include/ares_version.h
# https://github.com/nodejs/node/pull/9332
%global c_ares_version 1.34.4

# llhttp - from deps/llhttp/include/llhttp.h
%global llhttp_version 9.2.1

# libuv - from deps/uv/include/uv/version.h
%global libuv_version 1.49.2

# nghttp2 - from deps/nghttp2/lib/includes/nghttp2/nghttp2ver.h
%global nghttp2_version 1.64.0

# nghttp3 - from deps/ngtcp2/nghttp3/lib/includes/nghttp3/version.h
%global nghttp3_version 1.6.0

# ngtcp2 from deps/ngtcp2/ngtcp2/lib/includes/ngtcp2/version.h
%global ngtcp2_version 1.9.1

# ICU - from tools/icu/current_ver.dep
%global icu_major 76
%global icu_minor 1
%global icu_version %{icu_major}.%{icu_minor}

%global icudatadir %{nodejs_datadir}/icudata	
%{!?little_endian: %global little_endian %(%{__python3} -c "import sys;print (0 if sys.byteorder=='big' else 1)")}

# uvwasi - from deps/uvwasi/include/uvwasi.h
%global uvwasi_version 0.0.21

# histogram_c - assumed from timestamps
%global histogram_version 0.9.7

%global icu_flag small-icu

# simdutf from deps/simdutf/simdutf.h
%global simdutf_version 5.6.4

# punycode - from lib/punycode.js
# Note: this was merged into the mainline since 0.6.x
# Note: this will be unmerged in an upcoming major release
%global punycode_version 2.1.0

# npm - from deps/npm/package.json
#squidf: WARNING don't change the epoch
%global npm_epoch 1
%global npm_version 10.9.2

# In order to avoid needing to keep incrementing the release version for the
# main package forever, we will just construct one for npm that is guaranteed
# to increment safely. Changing this can only be done during an update when the
# base npm version number is increasing.
%global npm_release %{nodejs_epoch}.%{nodejs_major}.%{nodejs_minor}.%{nodejs_patch}.%{nodejs_release}

Name: nodejs
Epoch: %{nodejs_epoch}
Version: %{nodejs_version}
Release: %mkrel %{nodejs_release}
Summary: JavaScript runtime
License: MIT and ASL 2.0 and ISC and BSD
Group: Development/Other
URL: https://nodejs.org/


# nodejs bundles openssl, but we use the system version in Mageia
# because openssl contains prohibited code, we remove openssl completely from
# the tarball, using the script in Source100

Source0: node-v%{nodejs_version}-stripped.tar.xz
Source1: npmrc
Source2: btest402.js
Source3: https://github.com/unicode-org/icu/releases/download/release-%{icu_major}-%{icu_minor}/icu4c-%{icu_major}_%{icu_minor}-src.tgz
Source100: %{name}-tarball.sh
Source201: npmrc.builtin.in
Source202: nodejs.pc.in
Source203: v8.pc.in

Patch1: 0001-Remove-unused-OpenSSL-config.patch

BuildRequires: python3-devel
BuildRequires: zlib-devel
BuildRequires: brotli-devel
BuildRequires: chrpath
BuildRequires: libatomic-devel
BuildRequires: python3-jinja2
BuildRequires: jq
BuildRequires: ninja

%if %{with bootstrap}
Provides: bundled(libuv) = %{libuv_version}
Provides: bundled(nghttp2) = %{nghttp2_version}
Provides: bundled(nghttp3) = %{nghttp3_version}
Provides: bundled(ngtcp2) = %{ngtcp2_version}
# Temporarily bundle llhttp because the upstream doesn't
# provide releases for it.
Provides: bundled(llhttp) = %{llhttp_version}
%else
BuildRequires: nodejs-packaging
BuildRequires: systemtap
BuildRequires: http-parser-devel >= 2.9.2
BuildRequires: libuv-devel >= %{libuv_version}
BuildRequires: pkgconfig(libnghttp2) >= %{nghttp2_version}
%endif

BuildRequires: openssl-devel

# we need the system certificate store
Requires: ca-certificates


#we need ABI virtual provides where SONAMEs aren't enough/not present so deps
#break when binary compatibility is broken
Provides: nodejs(abi) = %{nodejs_abi}
Provides: nodejs(abi%{nodejs_major}) = %{nodejs_abi}
Provides: nodejs(v8-abi) = %{v8_abi}
Provides: nodejs(v8-abi%{v8_major}) = %{v8_abi}

#this corresponds to the "engine" requirement in package.json
Provides: nodejs(engine) = %{nodejs_version}

# The punycode module was absorbed into the standard library in v0.6.
# It still exists as a seperate package for the benefit of users of older
# versions.  Since we've never shipped anything older than v0.10 in Mageia,
# we don't need the seperate nodejs-punycode package, so we Provide it here so
# dependent packages don't need to override the dependency generator.
# See also: RHBZ#11511811
# UPDATE: punycode will be deprecated and so we should unbundle it in Node v8
# and use upstream module instead
# https://github.com/nodejs/node/commit/29e49fc286080215031a81effbd59eac092fff2f
Provides: nodejs-punycode = %{punycode_version}
Provides: npm(punycode) = %{punycode_version}

# Node.js has forked c-ares from upstream in an incompatible way, so we need
# to carry the bundled version internally.
# See https://github.com/nodejs/node/commit/766d063e0578c0f7758c3a965c971763f43fec85
Provides: bundled(c-ares) = %{c_ares_version}

# Node.js is closely tied to the version of v8 that is used with it. It makes
# sense to use the bundled version because upstream consistently breaks ABI
# even in point releases. Node.js upstream has now removed the ability to build
# against a shared system version entirely.
# See https://github.com/nodejs/node/commit/d726a177ed59c37cf5306983ed00ecd858cfbbef
Provides: bundled(v8) = %{v8_version}

# Node.js is bound to a specific version of ICU which may not match the OS
# We cannot pin the OS to this version of ICU because every update includes
# an ABI-break, so we'll use the bundled copy.
Provides: bundled(icu) = %{icu_version}

# Upstream added new dependencies, but so far they are not available in Fedora
# or there's no option to built it as a shared dependency, so we bundle them
Provides: bundled(uvwasi) = %{uvwasi_version}
Provides: bundled(histogram) = %{histogram_version}
Provides: bundled(simdutf) = %{simdutf_version}

# Make sure we keep NPM up to date when we update Node.js
Requires: npm = %mkrel %{npm_epoch}:%{npm_version}-%{npm_release}

#squidf: to help getting pwsh for corepack via a potential external RHEL dnf repo or other
Recommends: powershell

%description
Node.js is a platform built on Chrome's JavaScript runtime
for easily building fast, scalable network applications.
Node.js uses an event-driven, non-blocking I/O model that
makes it lightweight and efficient, perfect for data-intensive
real-time applications that run across distributed devices.

%package devel
Summary: JavaScript runtime - development headers
Group: Development/Other
Requires: %{name} = %mkrel %{epoch}:%{nodejs_version}-%{nodejs_release}
Requires: openssl-devel
Requires: zlib-devel
Requires: nodejs-packaging

%if %{with bootstrap}
# deps are bundled
%else
Requires: http-parser-devel
Requires: libuv-devel
%endif

%description devel
Development headers for the Node.js JavaScript runtime.

%package libs
Summary: Node.js and v8 libraries

# Compatibility for obsolete v8 package
%if 0%{?__isa_bits} == 64
Provides: libv8.so.%{v8_major}()(64bit)
Provides: libv8_libbase.so.%{v8_major}()(64bit)
Provides: libv8_libplatform.so.%{v8_major}()(64bit)
%else
# 32-bits
Provides: libv8.so.%{v8_major}
Provides: libv8_libbase.so.%{v8_major}
Provides: libv8_libplatform.so.%{v8_major}
%endif

Provides: v8 = %mkrel %{v8_epoch}:%{v8_version}-%{nodejs_release}
Provides: v8 = %mkrel %{v8_epoch}:%{v8_version}-%{nodejs_release}
Obsoletes: v8 < 1:6.7.17-10

%description libs
Libraries to support Node.js and provide stable v8 interfaces.


%package -n v8-devel
Summary: v8 - development headers
Epoch: %{v8_epoch}
Version: %mkrel %{v8_version}
Release: %mkrel %{v8_release}
Requires: %{name}-devel = %mkrel %{nodejs_epoch}:%{nodejs_version}-%{nodejs_release}

%description -n v8-devel
Development headers for the v8 runtime.

%package -n npm
Summary: Node.js Package Manager
Epoch: %{npm_epoch}
Version: %{npm_version}
Release: %mkrel %{npm_release}

Provides: npm = %{npm_epoch}:%{npm_version}
Requires: nodejs = %mkrel %{epoch}:%{nodejs_version}-%{nodejs_release}

# Do not add epoch to the virtual NPM provides or it will break
# the automatic dependency-generation script.
Provides: npm(npm) = %{npm_version}

%description -n npm
npm is a package manager for node.js. You can use it to install and publish
your node programs. It manages dependencies and does other cool stuff.

%package docs
Summary: Node.js API documentation
Group: Documentation
BuildArch: noarch

# We don't require that the main package be installed to
# use the docs, but if it is installed, make sure the
# version always matches
Conflicts: %{name} > %mkrel %{epoch}:%{nodejs_version}-%{nodejs_release}
Conflicts: %{name} < %mkrel %{epoch}:%{nodejs_version}-%{nodejs_release}

%description docs
The API documentation for the Node.js JavaScript runtime.


%prep
%autosetup -p1 -n node-v%{nodejs_version}

# remove bundled dependencies that we aren't building
rm -rf deps/zlib
rm -rf deps/brotli
rm -rf deps/v8/third_party/jinja2
rm -rf tools/inspector_protocol/jinja2

%if %{without bootstrap}
rm -rf deps/cjs-module-lexer
rm -rf deps/undici
%endif

# Replace any instances of unversioned python with python3
pfiles=( $(grep -rl python) )
%py3_shebang_fix ${pfiles[@]}


%build
%ifarch s390 s390x %{arm} %ix86
# Decrease debuginfo verbosity to reduce memory consumption during final
# library linking
%global optflags %(echo %{optflags} | sed 's/-g /-g1 /')
%endif

export CC='%{__cc}'
export CXX='%{__cxx}'

# build with debugging symbols and add defines from libuv (#892601)
export CFLAGS='%{optflags} \
               -D_LARGEFILE_SOURCE \
               -D_FILE_OFFSET_BITS=64 \
               -DZLIB_CONST \
               -O3 \
               -fno-ipa-icf'
export CXXFLAGS='%{optflags} \
                 -D_LARGEFILE_SOURCE \
                 -D_FILE_OFFSET_BITS=64 \
                 -DZLIB_CONST \
                 -O3 \
                 -fno-ipa-icf'

# Explicit new lines in C(XX)FLAGS can break naive build scripts
export CFLAGS="$(echo ${CFLAGS} | tr '\n\\' '  ')"
export CXXFLAGS="$(echo ${CXXFLAGS} | tr '\n\\' '  ')"
export LDFLAGS="%{build_ldflags}"

%if %{with bootstrap}
#squidf: to find system openssl3 modules
export OPENSSL_CONF=%{_sysconfdir}/pki/tls/openssl.cnf
export OPENSSL_MODULES=%{_libdir}/ossl-modules
#
%{__python3} configure.py --prefix=%{_prefix} \
           --shared \
           --ninja \
           --libdir=%{_lib} \
           --shared-openssl \
           --shared-openssl-libpath=%{_libdir} \
           --shared-openssl-includes=%{_includedir} \
           --shared-openssl-libname=crypto,ssl \
           --openssl-is-fips \
           --shared-zlib \
           --shared-brotli \
           --with-intl=small-icu \
           --debug-nghttp2 \
           --openssl-use-def-ca-store
%else
%{__python3} configure.py --prefix=%{_prefix} \
           --ninja \
           --shared \
           --libdir=%{_lib} \
           --shared-openssl \
           --openssl-is-fips \
           --shared-zlib \
           --shared-brotli \
           --shared-libuv \
           --shared-nghttp2 \
           --with-dtrace \
           --with-intl=%{icu_flag} \
           --with-icu-default-data-dir=%{icudatadir} \
           --debug-nghttp2 \
           --openssl-use-def-ca-store
%endif

%ninja_build -C out/Release

# Extract the ICU data and convert it to the appropriate endianness
pushd deps/
tar xfz %SOURCE3	
pushd icu/source

mkdir -p converted
	
%if 0%{?little_endian}
# The little endian data file is included in the ICU sources
install -Dpm0644 data/in/icudt%{icu_major}l.dat converted/
	
%else
# For the time being, we need to build ICU and use the included `icupkg` tool
# to convert the little endian data file into a big-endian one.
# At some point in the future, ICU releases will start including both data
# files and we should switch to those.	
mkdir -p data/out/tmp

%configure
%make_build
icu_root=$(pwd)
LD_LIBRARY_PATH=./lib ./bin/icupkg -tb data/in/icudt%{icu_major}l.dat \
                                       converted/icudt%{icu_major}b.dat	
%endif

popd # icu/source
popd # deps

%install
 
# The ninja build does not put the shared library in the expected location, so
# we will move it.
mv out/Release/lib/libnode.so.%{nodejs_soversion} out/Release/
./tools/install.py --dest-dir %{buildroot} --prefix %{_prefix} install

# Set the binary permissions properly
chmod 0755 %{buildroot}/%{_bindir}/node
chrpath --delete %{buildroot}%{_bindir}/node

# Set the hashbang to use the matching Node.js interpreter
sed --in-place --regexp-extended \
    's;^#!/usr/bin/env node($|\ |\t)+;#!/usr/bin/node;g' \
    %{buildroot}%{nodejs_default_sitelib}/npm/bin/npm-cli.js

ln -srf %{buildroot}%{nodejs_default_sitelib}/npm/bin/npm-cli.js \
        %{buildroot}%{_bindir}/npm

# Set the hashbang to use the matching Node.js interpreter
sed --in-place --regexp-extended \
    's;^#!/usr/bin/env node($|\ |\t)+;#!/usr/bin/node;g' \
    %{buildroot}%{nodejs_default_sitelib}/npm/bin/npx-cli.js

ln -srf %{buildroot}%{nodejs_default_sitelib}/npm/bin/npx-cli.js \
        %{buildroot}%{_bindir}/npx

# Install library symlink
ln -s %{_libdir}/libnode.so.%{nodejs_soversion} %{buildroot}%{_libdir}/libnode.so

# Install v8 compatibility symlinks
for header in %{buildroot}%{_includedir}/node/libplatform %{buildroot}%{_includedir}/node/v8*.h; do
    header=$(basename ${header})
    ln -s %{_includedir}/node/${header} %{buildroot}%{_includedir}/${header}
done
#squidf: solve mga#28809
ln -s ./node/cppgc %{buildroot}%{_includedir}/cppgc
for soname in libv8 libv8_libbase libv8_libplatform; do
  ln -srf %{buildroot}%{_libdir}/libnode.so.%{nodejs_soversion} %{buildroot}%{_libdir}/${soname}.so.%{v8_major}.%{v8_minor}
  ln -srf %{buildroot}%{_libdir}/libnode.so.%{nodejs_soversion} %{buildroot}%{_libdir}/${soname}.so
  ln -srf %{buildroot}%{_libdir}/libnode.so.%{nodejs_soversion} %{buildroot}%{_libdir}/${soname}.so.%{v8_major}
done

# own the sitelib directory
mkdir -p %{buildroot}%{nodejs_default_sitelib}

#install documentation
mkdir -p %{buildroot}%{_pkgdocdir}/html
cp -pr doc/* %{buildroot}%{_pkgdocdir}/html
rm -f %{buildroot}%{_pkgdocdir}/html/nodejs.1

#node-gyp needs common.gypi too
mkdir -p %{buildroot}%{_datadir}/node
cp -p common.gypi %{buildroot}%{_datadir}/node

# Install the GDB init tool into the documentation directory
mv %{buildroot}/%{_datadir}/doc/node/gdbinit %{buildroot}/%{_pkgdocdir}/gdbinit

# install NPM docs to mandir
mkdir -p %{buildroot}%{_mandir} \
         %{buildroot}%{_pkgdocdir}/npm

cp -pr deps/npm/man/* %{buildroot}%{_mandir}/
rm -rf %{buildroot}%{nodejs_default_sitelib}/npm/man
ln -sf %{_mandir}  %{buildroot}%{nodejs_default_sitelib}/npm/man


# Install Gatsby HTML documentation to %%{_pkgdocdir}
cp -pr deps/npm/docs %{buildroot}%{_pkgdocdir}/npm/
rm -rf %{buildroot}%{nodejs_default_sitelib}/npm/docs

ln -sf %{_pkgdocdir}/npm %{buildroot}%{nodejs_default_sitelib}/npm/docs

# Node tries to install some python files into a documentation directory
# (and not the proper one). Remove them for now until we figure out what to
# do with them.
rm -f %{buildroot}/%{_defaultdocdir}/node/lldb_commands.py \
      %{buildroot}/%{_defaultdocdir}/node/lldbinit

# Some NPM bundled deps are executable but should not be. This causes
# unnecessary automatic dependencies to be added. Make them not executable.
# Skip the npm bin directory or the npm binary will not work.
find %{buildroot}%{nodejs_default_sitelib}/npm \
    -not -path "%{buildroot}%{nodejs_default_sitelib}/npm/bin/*" \
    -executable -type f \
    -exec chmod -x {} \;

# The above command is a little overzealous. Add a few permissions back.
chmod 0755 %{buildroot}%{nodejs_default_sitelib}/npm/node_modules/@npmcli/run-script/lib/node-gyp-bin/node-gyp
chmod 0755 %{buildroot}%{nodejs_default_sitelib}/npm/node_modules/node-gyp/bin/node-gyp.js

# Corepack contains a number of executable"shims", including some for Windows
# PowerShell. Drop the executable bit for those so we don't pick up an
# automatic dependency on /usr/bin/pwsh that we cannot satisfy.
chmod -x %{buildroot}%{nodejs_default_sitelib}/corepack/shims/*.ps1

# Set the hashbang to use the matching Node.js interpreter
sed --in-place --regexp-extended \
    's;^#!/usr/bin/env node($|\ |\t)+;#!/usr/bin/node;g' \
    %{buildroot}%{nodejs_default_sitelib}/npm/node_modules/node-gyp/bin/node-gyp.js

# Drop the NPM builtin configuration in place
sed -e 's#@SYSCONFDIR@#%{_sysconfdir}#g' \
    %{SOURCE201} > %{buildroot}%{nodejs_default_sitelib}/npm/npmrc

# Drop the NPM default configuration in place
mkdir -p %{buildroot}%{_sysconfdir}
cp %{SOURCE1} %{buildroot}%{_sysconfdir}/npmrc

# NPM upstream expects it to be in /usr/etc/npmrc, so we'll put a symlink here
# This is done in the interests of keeping /usr read-only.
mkdir -p %{buildroot}%{_prefix}/etc
ln -s %{_sysconfdir}/npmrc %{buildroot}%{_prefix}/etc/npmrc

# Install the full-icu data files
install -Dpm0644 -t %{buildroot}%{icudatadir} deps/icu/source/converted/*

# Add pkg-config files
mkdir -p %{buildroot}%{_libdir}/pkgconfig
sed -e 's#@PREFIX@#%{_prefix}#g' \
    -e 's#@INCLUDEDIR@#%{_includedir}#g' \
    -e 's#@LIBDIR@#%{_libdir}#g' \
    -e 's#@PKGCONFNAME@#nodejs#g' \
    -e 's#@NODEJS_VERSION@#%{nodejs_version}#g' \
    %{SOURCE202} > %{buildroot}%{_libdir}/pkgconfig/nodejs.pc

sed -e 's#@PREFIX@#%{_prefix}#g' \
    -e 's#@INCLUDEDIR@#%{_includedir}#g' \
    -e 's#@LIBDIR@#%{_libdir}#g' \
    -e 's#@PKGCONFVERSION@#v8-%{v8_major}.%{v8_minor}#g' \
    -e 's#@V8_VERSION@#%{v8_version}#g' \
    %{SOURCE203} > %{buildroot}%{_libdir}/pkgconfig/v8-%{v8_major}.%{v8_minor}.pc


%check
# Fail the build if the versions don't match
LD_LIBRARY_PATH=%{buildroot}%{_libdir} %{buildroot}/%{_bindir}/node -e "require('assert').equal(process.versions.node, '%{nodejs_version}')"
LD_LIBRARY_PATH=%{buildroot}%{_libdir} %{buildroot}/%{_bindir}/node -e "require('assert').equal(process.versions.v8.replace(/-node\.\d+$/, ''), '%{v8_version}')"
LD_LIBRARY_PATH=%{buildroot}%{_libdir} %{buildroot}/%{_bindir}/node -e "require('assert').equal(process.versions.ares.replace(/-DEV$/, ''), '%{c_ares_version}')"

# Ensure we have punycode and that the version matches
LD_LIBRARY_PATH=%{buildroot}%{_libdir} %{buildroot}/%{_bindir}/node -e "require(\"assert\").equal(require(\"punycode\").version, '%{punycode_version}')"

# Ensure we have npm and that the version matches
LD_LIBRARY_PATH=%{buildroot}%{_libdir} %{buildroot}/%{_bindir}/npm version --json |jq '. | select(.npm | contains("%{npm_version}"))'


%files
%{_bindir}/node
%dir %{nodejs_default_sitelib}
%dir %{_datadir}/node
# corepack
%{_bindir}/corepack
%{nodejs_default_sitelib}/corepack

%dir %{icudatadir}
%{icudatadir}/icudt%{icu_major}*.dat

%if %{with bootstrap}
# no dtrace
%else
%dir %{_usr}/lib/dtrace
%{_usr}/lib/dtrace/node.d
%endif

%license LICENSE
%doc CHANGELOG.md GOVERNANCE.md README.md
%doc %{_mandir}/man1/node.1*


%files devel
%{_includedir}/node
%{_libdir}/libnode.so
%{_datadir}/node/common.gypi
%{_pkgdocdir}/gdbinit
%{_libdir}/pkgconfig/nodejs.pc

%files libs
%license LICENSE
%{_libdir}/libnode.so.%{nodejs_soversion}
%{_libdir}/libv8.so.%{v8_major}.%{v8_minor}
%{_libdir}/libv8_libbase.so.%{v8_major}.%{v8_minor}
%{_libdir}/libv8_libplatform.so.%{v8_major}.%{v8_minor}
%dir %{nodejs_datadir}/
%{_libdir}/libv8.so.%{v8_major}
%{_libdir}/libv8_libbase.so.%{v8_major}
%{_libdir}/libv8_libplatform.so.%{v8_major}


%files -n v8-devel
%{_includedir}/libplatform
%{_includedir}/v8*.h
%{_includedir}/cppgc
%{_libdir}/libv8.so
%{_libdir}/libv8_libbase.so
%{_libdir}/libv8_libplatform.so
%{_libdir}/pkgconfig/v8-%{v8_major}.%{v8_minor}.pc


%files -n npm
%{_bindir}/npm
%{_bindir}/npx
%{nodejs_default_sitelib}/npm
%{_prefix}/etc/npmrc
%ghost %{_sysconfdir}/npmrc
%ghost %{_sysconfdir}/npmignore
%doc %{_mandir}/man1/*.1.xz
%doc %{_mandir}/man5/*.5.xz
%doc %{_mandir}/man7/*.7.xz

%files docs
%dir %{_pkgdocdir}
%{_pkgdocdir}/html
%{_pkgdocdir}/npm/docs


%changelog
* Fri Feb 14 2025 daviddavid <daviddavid> 1:22.13.1-3.mga10
+ Revision: 2148803
- fix libs target in nodejs.pc file, should be '-lnode' instead of '-lnodejs'

* Tue Feb 04 2025 ns80 <ns80> 1:22.13.1-2.mga10
+ Revision: 2145101
- new version 22.13.1 for CVE-2025-2308[35] (mga#33947)

* Mon Aug 19 2024 squidf <squidf> 1:22.6.0-1.mga10
+ Revision: 2086998
- Fix build flags
- Update files section
- Update to 22.6.0
- Add pkg-config files
- New version 20.12.1

* Fri Mar 29 2024 squidf <squidf> 1:20.12.0-1.mga10
+ Revision: 2053096
- New version 20.12.0
- Update icu to 74.2

* Sun Mar 17 2024 squidf <squidf> 1:20.11.1-1.mga10
+ Revision: 2050208
- Update to 20.11.1
- Update patch
- Update and clean spec

* Sun Feb 18 2024 daviddavid <daviddavid> 1:18.19.1-2.mga10
+ Revision: 2042292
- Replace /usr/etc/npmrc symlink with builtin configuration
    We want to have the system-level npmrc located at /etc/npmrc.
    By default, npm looks for it in /usr/etc/npmrc,
    so we placed a symlink to /etc/npmrc there.
    However, we are the only known package that has anything in /usr/etc,
    which confuses and/or breaks various tooling.
    This gets rid of the symlink,
    and instead uses "builtin"-level configuration of npm
    to cause it to load the system-level configuration from /etc/npmrc.

* Fri Feb 16 2024 squidf <squidf> 1:18.19.1-1.mga10
+ Revision: 2042003
- New version 18.19.1

* Mon Oct 16 2023 squidf <squidf> 1:18.18.2-1.mga10
+ Revision: 1997822
- New version: 18.18.2
- Use icu 73.2
- Update npm to 9.8.1

* Wed Aug 16 2023 squidf <squidf> 1:18.17.1-1.mga10
+ Revision: 1964707
- New version: 18.17.1 (mga#32176)
- Fix v8 headers symlink (mga#28809)
- Update icu to 73.1

* Mon Jun 26 2023 squidf <squidf> 1:18.16.1-2.mga9
+ Revision: 1963159
+ rebuild (emptylog)

* Sat Jun 24 2023 squidf <squidf> 1:18.16.1-1.mga9
+ Revision: 1962970
- New version: 18.16.1

* Sat Apr 15 2023 squidf <squidf> 1:18.16.0-1.mga9
+ Revision: 1953064
- Fix doc in Files section
- New version: 18.16.0
- Update patch

* Sat Feb 18 2023 squidf <squidf> 1:18.14.1-1.mga9
+ Revision: 1943878
- New version: 18.14.1 (MGA#31559)
- Update patch

* Sun Jan 08 2023 squidf <squidf> 1:18.13.0-1.mga9
+ Revision: 1931601
- Update patch
- New version: 18.13.0
- Update icu to 72.1

* Sat Nov 05 2022 squidf <squidf> 1:18.12.1-1.mga9
+ Revision: 1903854
- New version: 18.12.1
- New LTS branch from 18.12.0
- Fix CVE-2022-43548

* Tue Sep 27 2022 squidf <squidf> 1:18.9.1-2.mga9
+ Revision: 1892737
- New version: 18.9.1 (mga#30887)
- Update patch
- Remove absent systemtap from files section

* Sat Aug 27 2022 joequant <joequant> 1:18.7.0-2.mga9
+ Revision: 1880975
- update to 18.7.0
+ neoclust <neoclust>
- New version 16.16.0

* Thu Mar 24 2022 joequant <joequant> 1:16.14.0-2.mga9
+ Revision: 1825265
- increase v8 release
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Mar 08 2022 joequant <joequant> 1:16.14.0-1.mga9
+ Revision: 1789779
- update release
- update to 16.14
+ neoclust <neoclust>
- New version 16.14.0

* Tue Jan 18 2022 neoclust <neoclust> 1:16.13.2-1.mga9
+ Revision: 1768974
- New version 16.13.2: Fixes  CVE-2021-4453[1-3] and CVE-2022-21824 (mga#29872)

* Sun Jan 09 2022 joequant <joequant> 1:16.13.1-1.mga9
+ Revision: 1767365
- update to 16.3.1

* Thu Oct 21 2021 joequant <joequant> 1:16.11.1-1.mga9
+ Revision: 1752453
- update to 16.11.1

* Sun Oct 03 2021 joequant <joequant> 1:16.10.0-1.mga9
+ Revision: 1748706
- add jinja2
- update to 16.10.0
+ wally <wally>
- rebuild for openssl 3.0.0
+ neoclust <neoclust>
- New version v16.10.0

* Sat Jul 31 2021 neoclust <neoclust> 1:16.6.0-1.mga9
+ Revision: 1738303
- New version 16.6.0

* Tue Jul 20 2021 joequant <joequant> 1:16.5.0-1.mga9
+ Revision: 1737246
- update to 16.5.0

* Sun Jul 04 2021 joequant <joequant> 1:16.4.1-1.mga9
+ Revision: 1734632
- update to 16.4.1

* Wed May 05 2021 joequant <joequant> 1:16.0.0-1.mga9
+ Revision: 1721379
- update to 16.0.0

* Mon Apr 19 2021 neoclust <neoclust> 1:14.16.0-4.mga9
+ Revision: 1717148
- Add cppgc include dir (mga#28809)

* Sun Feb 28 2021 neoclust <neoclust> 1:14.16.0-3.mga9
+ Revision: 1694247
- npm release is now 6.14.11
- New version: Fixes CVE-2021-22883, CVE-2021-22884 (mga#28445)

* Tue Jan 05 2021 neoclust <neoclust> 1:14.15.1-3.mga8
+ Revision: 1669030
- Add P100 and P101 to fix CVE-2020-8265 and CVE-2020-8287

* Tue Dec 01 2020 luigiwalser <luigiwalser> 1:14.15.1-2.mga8
+ Revision: 1651140
- rebuild for icu

* Thu Nov 26 2020 joequant <joequant> 1:14.15.1-1.mga8
+ Revision: 1649491
- fix v8 release
- update to 14.15.1 - fix CVE-2020-8277

* Sun Oct 25 2020 joequant <joequant> 1:14.14.0-1.mga8
+ Revision: 1639207
- update to 14.14.0

* Tue Oct 13 2020 joequant <joequant> 1:14.13.1-1.mga8
+ Revision: 1635246
- bump v8-devel
- update to 14.13.1

* Fri Sep 25 2020 joequant <joequant> 1:14.12.0-1.mga8
+ Revision: 1629981
- update to 14.12 to fix security holes

* Mon Sep 07 2020 joequant <joequant> 1:14.9.0-1.mga8
+ Revision: 1623355
- bump v8
- fix v8-devel
- bump v8-release
- bump version for v8-devel
- update 14.9.0

* Wed Jul 22 2020 joequant <joequant> 1:14.6.0-3.mga8
+ Revision: 1607748
- update to 14.6.0

* Sat Jun 27 2020 joequant <joequant> 1:14.4.0-3.mga8
+ Revision: 1599457
- fix macros
- fix debug flag
- fix linking flags to prevent memory errors
- throttle cpus
- single thread to reduce memory
- update to 14.4.0

* Sun Jun 07 2020 kekepower <kekepower> 1:12.18.0-6.mga8
+ Revision: 1590807
- Update to version 12.18.0

* Wed May 06 2020 joequant <joequant> 1:12.16.3-5.mga8
+ Revision: 1581009
- add atomic-devel
- fix bootstrap

* Wed May 06 2020 joequant <joequant> 1:12.16.3-4.mga8
+ Revision: 1580999
- add systemtap
- update to 12.16.3 with python3
+ danf <danf>
- Switch URLs from http: to https:

* Wed Jan 29 2020 daviddavid <daviddavid> 1:12.9.0-4.mga8
+ Revision: 1485172
- fix epoch on v8-devel package

* Sat Oct 12 2019 pterjan <pterjan> 1:12.9.0-3.mga8
+ Revision: 1452345
- Use -g1 to reduce memory usage on arm (from Fedora)

* Thu Oct 10 2019 pterjan <pterjan> 1:12.9.0-2.mga8
+ Revision: 1451086
- Bootstrap for armv7hl

* Sun Aug 25 2019 joequant <joequant> 1:12.9.0-1.mga8
+ Revision: 1431807
- update to 12.9.0

* Sat Aug 17 2019 kekepower <kekepower> 1:10.16.3-3.mga8
+ Revision: 1429593
- Bump rel
- Update to version 10.16.3 to fix CVE-2019-95[11-18] (mga#25314)

* Tue Jul 09 2019 kekepower <kekepower> 1:10.16.0-2.mga8
+ Revision: 1419790
- Fix v8-devel package version
- Update to version 10.16.0

* Mon Apr 22 2019 kekepower <kekepower> 1:10.15.3-8.mga7
+ Revision: 1394850
- Revert most of the previous changes
- Fixed a typo in a Requires for zlib-devel

* Mon Apr 22 2019 joequant <joequant> 1:10.15.3-6.mga7
+ Revision: 1394741
- run without bootstrap
- run bootstrap for arm

* Mon Apr 22 2019 joequant <joequant> 1:10.15.3-4.mga7
+ Revision: 1394683
- build non-bootstrap with 10.15.3

* Mon Apr 22 2019 joequant <joequant> 1:10.15.3-3.mga7
+ Revision: 1394644
- bootstrap
- fix up broken package
+ kekepower <kekepower>
- Bootstrap build
- Relax BR requirements for http-parser-devel
- Remove Requires for nghttp

* Sun Apr 21 2019 kekepower <kekepower> 1:10.15.3-2.mga7
+ Revision: 1394478
- Update to version 10.15.3

* Wed Jan 02 2019 kekepower <kekepower> 1:10.14.2-2.1.mga7
+ Revision: 1348619
- Update to version 10.14.2

* Mon Dec 31 2018 tv <tv> 1:10.13.0-2.mga7
+ Revision: 1347319
- rebuild with latest icu

* Sat Nov 10 2018 joequant <joequant> 1:10.13.0-1.mga7
+ Revision: 1329304
- upgrade to 10.13.0

* Tue Sep 04 2018 joequant <joequant> 1:10.9.0-1.mga7
+ Revision: 1256930
- upgrade to 10.9.0

* Mon Sep 03 2018 joequant <joequant> 1:8.11.4-1.mga7
+ Revision: 1256748
- use local icu rather than system icu
- rebuild with new libraries
+ tv <tv>
- rebuild for new libicu

* Mon Jul 02 2018 joequant <joequant> 1:8.11.3-2.mga7
+ Revision: 1241247
- try relinking against libuv

* Wed Jun 13 2018 kekepower <kekepower> 1:8.11.3-1.mga7
+ Revision: 1236790
- Update to version 8.11.3 (mga#21330)

* Sun May 20 2018 kekepower <kekepower> 1:8.11.2-1.mga7
+ Revision: 1230789
- Update to version 8.11.2

* Tue May 01 2018 daviddavid <daviddavid> 1:8.11.1-2.mga7
+ Revision: 1224186
- fix requires on devel subpkg

* Mon Apr 30 2018 kekepower <kekepower> 1:8.11.1-1.mga7
+ Revision: 1223856
- Update to version 8.11.1 LTS
- Enable shared-nghttp2
- Edited the spec file a little

* Sun Dec 31 2017 joequant <joequant> 1:8.9.3-1.mga7
+ Revision: 1188224
- upgrade to 8.9.3

* Fri Dec 29 2017 wally <wally> 1:8.4.0-4.mga7
+ Revision: 1186995
- rebuild for new icu

* Tue Nov 21 2017 tv <tv> 1:8.4.0-3.mga7
+ Revision: 1178553
- rebuild for new openssl

* Mon Nov 06 2017 mjack <mjack> 1:8.4.0-2.mga7
+ Revision: 1176260
+ rebuild (emptylog)

* Mon Sep 04 2017 cjw <cjw> 1:8.4.0-1.mga7
+ Revision: 1151179
- fix nodejs-devel deps
- build against compat-openssl10-devel
- fix npm package release number
+ neoclust <neoclust>
- Switch to LTS 8

* Fri Jul 28 2017 shlomif <shlomif> 1:6.11.1-5.mga7
+ Revision: 1132210
- Fix requires and provides.

* Fri Jul 28 2017 shlomif <shlomif> 1:6.11.1-4.mga7
+ Revision: 1132189
- bump rel
+ neoclust <neoclust>
- Remove ca-certificates deps

* Thu Jul 27 2017 neoclust <neoclust> 1:6.11.1-3.mga7
+ Revision: 1131357
- Rebuild with fixed versions
- Relax requires
- New version v6.11.1

* Fri May 05 2017 neoclust <neoclust> 1:6.10.3-2.mga6
+ Revision: 1099146
- Rebuild because of missing package

* Thu May 04 2017 neoclust <neoclust> 1:6.10.3-1.mga6
+ Revision: 1099118
- New version 6.10.3 (LTS)

* Thu May 04 2017 neoclust <neoclust> 1:6.10.2-1.mga6
+ Revision: 1099101
- New version v6.10.2 ( LTS )
- New version 6.9.2

* Wed Mar 15 2017 mrambo3501 <mrambo3501> 1:6.9.1-3.mga6
+ Revision: 1092754
- Rebuild for icu-58.2

* Sun Dec 11 2016 ngompa <ngompa> 1:6.9.1-2.mga6
+ Revision: 1074259
- Convert %%pretrans to Lua

* Sat Nov 12 2016 shlomif <shlomif> 1:6.9.1-1.mga6
+ Revision: 1066886
- New stable version v6.9.1.

* Thu Sep 08 2016 luigiwalser <luigiwalser> 1:4.5.0-1.mga6
+ Revision: 1050787
- 4.5.0 (sync with f24)
- split npm into a subpackage
- build Node.js with internationalization support

* Wed May 25 2016 neoclust <neoclust> 1:4.4.4-3.mga6
+ Revision: 1018324
- Rebuild for ARM

* Tue May 17 2016 tv <tv> 1:4.4.4-2.mga6
+ Revision: 1016533
- fix upgrade

* Tue May 17 2016 neoclust <neoclust> 1:4.4.4-1.mga6
+ Revision: 1016407
- Update to latest LTS security release (4.4.4)
  https://github.com/nodejs/node/blob/v4.4.4/CHANGELOG.md
  https://lwn.net/Articles/686158/

* Mon May 16 2016 neoclust <neoclust> 6.1.0-5.mga6
+ Revision: 1016185
- Add conflict to ease upgrade

* Mon May 16 2016 neoclust <neoclust> 6.1.0-4.mga6
+ Revision: 1016066
- Remove useless epoch

* Mon May 16 2016 joequant <joequant> 1:6.1.0-3.mga6
+ Revision: 1015965
- change requires from ca-certificates -> rootcerts

* Mon May 16 2016 neoclust <neoclust> 1:6.1.0-2.mga6
+ Revision: 1015842
- Fix ExclusiveArch
- New version 6.1.0

* Mon Apr 25 2016 joequant <joequant> 5.11.0-1.mga6
+ Revision: 1005991
- update to 5.11.0

* Wed Mar 16 2016 tv <tv> 5.6.0-3.mga6
+ Revision: 992158
- resync patches with FC (thus fixing build)

* Wed Mar 02 2016 umeabot <umeabot> 5.6.0-2.mga6
+ Revision: 983804
- Rebuild for openssl

* Mon Feb 15 2016 joequant <joequant> 5.6.0-1.mga6
+ Revision: 961716
- update to 5.6.0 - fixes 17779

* Fri Jan 15 2016 joequant <joequant> 5.4.1-1.mga6
+ Revision: 923221
- upgrade to 5.4.1

* Sat Dec 19 2015 joequant <joequant> 5.3.0-2.mga6
+ Revision: 912183
- disable debug builds for arm

* Sat Dec 19 2015 joequant <joequant> 5.3.0-1.mga6
+ Revision: 912136
- upgrade to 5.3.0

* Sat Dec 19 2015 joequant <joequant> 4.2.3-2.mga6
+ Revision: 912125
- change category
- fix category
- upgrade to 4.2.3

* Thu Jul 30 2015 joequant <joequant> 0.10.40-1.mga6
+ Revision: 859093
- update to 0.10.40 and include node-gyp

* Sun May 03 2015 joequant <joequant> 0.10.38-1.mga5
+ Revision: 821164
- update to 0.10.38 to fix security issues in bug 15405

* Mon Oct 27 2014 luigiwalser <luigiwalser> 0.10.33-1.mga5
+ Revision: 793974
- 0.10.33

* Wed Oct 15 2014 umeabot <umeabot> 0.10.30-6.mga5
+ Revision: 750309
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.10.30-5.mga5
+ Revision: 726006
- add native deps support from FC

* Fri Sep 26 2014 tv <tv> 0.10.30-4.mga5
+ Revision: 725139
- rebuild for bogus file deps

* Wed Sep 17 2014 joequant <joequant> 0.10.30-3.mga5
+ Revision: 693134
- fix deps for nodejs
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sat Aug 16 2014 dams <dams> 0.10.30-1.mga5
+ Revision: 664405
- new version 0.10.30

* Wed Jul 23 2014 dams <dams> 0.10.29-1.mga5
+ Revision: 655770
- new version 0.10.29

* Fri May 02 2014 dams <dams> 0.10.28-1.mga5
+ Revision: 619739
- new version 0.10.28

* Mon Feb 24 2014 dams <dams> 0.10.26-1.mga5
+ Revision: 596210
- new version 0.10.26

* Tue Feb 04 2014 dams <dams> 0.10.25-1.mga5
+ Revision: 580750
- new version 0.10.25

* Mon Dec 23 2013 dams <dams> 0.10.24-1.mga4
+ Revision: 560066
- new version 0.10.24

* Wed Nov 20 2013 dams <dams> 0.10.22-1.mga4
+ Revision: 552078
- new version 0.10.22

* Wed Oct 23 2013 dams <dams> 0.10.21-1.mga4
+ Revision: 546474
- new version 0.10.21 (DoS Vulnerability)

* Mon Oct 21 2013 umeabot <umeabot> 0.10.20-2.mga4
+ Revision: 538513
- Mageia 4 Mass Rebuild

* Tue Oct 01 2013 dams <dams> 0.10.20-1.mga4
+ Revision: 489822
- new version 0.10.20
- new version 0.10.20

* Wed Sep 25 2013 dams <dams> 0.10.19-1.mga4
+ Revision: 485929
- new version 0.10.19

* Thu Sep 05 2013 dams <dams> 0.10.18-1.mga4
+ Revision: 475233
- new version 0.10.18

* Mon Aug 26 2013 dams <dams> 0.10.17-1.mga4
+ Revision: 471919
- new version 0.10.17

* Sat Jul 27 2013 dams <dams> 0.10.15-1.mga4
+ Revision: 458753
- new version 0.10.15

* Mon Jul 15 2013 dams <dams> 0.10.13-1.mga4
+ Revision: 454553
- new version 0.10.13

* Wed Jun 19 2013 dams <dams> 0.10.12-1.mga4
+ Revision: 445084
- new version 0.10.12

* Thu Jun 13 2013 dams <dams> 0.10.11-1.mga4
+ Revision: 442902
- new version 0.10.11

* Sat Jun 08 2013 dams <dams> 0.10.10-1.mga4
+ Revision: 440640
- new version 0.10.10

* Fri May 31 2013 dams <dams> 0.10.9-1.mga4
+ Revision: 433721
- new version 0.10.9

* Mon May 27 2013 dams <dams> 0.10.8-1.mga4
+ Revision: 428717
- new version 0.10.8

* Thu May 23 2013 dams <dams> 0.10.7-1.mga4
+ Revision: 425004
- new version 0.10.7

* Thu Apr 11 2013 dams <dams> 0.10.3-2.mga3
+ Revision: 409688
- now use bundled v8 as requested by Luigi12 to avoid using buggy v8 package

* Sat Apr 06 2013 dams <dams> 0.10.3-1.mga3
+ Revision: 408511
- new version 0.10.3

* Tue Apr 02 2013 dams <dams> 0.10.2-1.mga3
+ Revision: 407207
- new version 0.10.2

* Fri Mar 29 2013 dams <dams> 0.10.1-1.mga3
+ Revision: 406472
- disable doc for now
- new stable version 0.10.1
- clean and update BR
- add a 'docs' subpackage
- make sure we are not using bundled deps

* Sat Feb 09 2013 fwang <fwang> 0.9.9-1.mga3
+ Revision: 397647
- use shared cares
- update file list
- new version 0.9.9
- rebuild for new v8

* Sat Feb 09 2013 fwang <fwang> 0.9.0-4.mga3
+ Revision: 397503
- rebuild for new v8
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Sep 24 2012 fedya <fedya> 0.9.0-2.mga3
+ Revision: 297232
- Provides: npm see #820

* Mon Jul 30 2012 shlomif <shlomif> 0.9.0-1.mga3
+ Revision: 276171
- New version 0.9.0 thanks to fedya.
+ dmorgan <dmorgan>
- New version 0.8.1

* Wed Jan 11 2012 fwang <fwang> 0.4.12-1.mga2
+ Revision: 195003
- new version 0.4.12
+ misc <misc>
- new version
+ shikamaru <shikamaru>
- imported package nodejs


* Sat Mar 26 2011 Rémy Clouard <shikamaru@mandriva.org> 0.4.3-1.mga1
- initial package
